@@ -13,10 +13,10 @@ our @ISA = qw(Exporter);
 # see https://perlmonks.org/?node_id=11115288
 our (@EXPORT_OK, %EXPORT_TAGS);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 BEGIN {
-	$VERSION = '0.02';
+	$VERSION = '0.03';
 	if ($] > 5.006) {
 		require XSLoader;
 		XSLoader::load(__PACKAGE__, $VERSION);
@@ -75,7 +75,7 @@ String::Random::Regexp::regxstring - Generate random strings from a regular expr
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,51 @@ The generated random strings will be returned back as an ARRAY ref.
 C<undef> is returned on error, e.g. when no regular expression was
 specified or when the number of random strings to generate is not positive.
 
+=head1 THE C++ LIBRARY regxstring by daidodo
+
+This is a L<regxstring C++ library by daidodo|https://github.com/daidodo/regxstring>
+which produces random strings from a regular expresssion. According to the
+author, "I<... most Perl 5 supported regular expressions are also supported by regxstring, as showing bellow:>"
+
+    Meta-character(s)   Description
+    --------------------------------
+    \                   Quote the next meta-character
+    ^                   Match the beginning of the line
+    $                   Match the end of the line (or before newline at the end)
+    ?                   Match 1 or 0 times
+    +                   Match 1 or more times
+    *                   Match 0 or more times
+    {n}                 Match exactly n times
+    {n,}                Match at least n times
+    {n,m}               Match at least n but not more than m times
+    .                   Match any character (except newline)
+    (pattern)           Grouping
+    (?:pattern)         This is for clustering, not capturing; it groups sub-expressions like "()", but doesn't make back-references as "()" does
+    (?=pattern)         A zero-width positive look-ahead assertion, e.g., \w+(?=\t) matches a word followed by a tab, without including the tab
+    (?!pattern)         A zero-width negative look-ahead assertion, e.g., foo(?!bar) matches any occurrence of "foo" that isn't followed by "bar"
+    |                   Alternation
+    [xyz]               Matches a single character that is contained within the brackets
+    [^xyz]              Matches a single character that is not contained within the brackets
+    [a-z]               Matches a single character that is in a given range
+    [^a-z]              Matches a single character that is not in a given range
+    \f                  Form feed
+    \n                  Newline
+    \r                  Return
+    \t                  Tab
+    \v                  Vertical white space
+    \d                  Digits, [0-9]
+    \D                  Non-digits, [^0-9]
+    \s                  Space and tab, [ \t\r\n\f]
+    \S                  Non-white space characters, [^ \t\r\n\f]
+    \w                  Alphanumeric characters plus '_', [0-9a-zA-Z_]
+    \W                  Non-word characters, [^0-9a-zA-Z_]
+    \N                  Matches what the Nth marked sub-expression matched, where N is a digit from 1 to 9
+
+The library provides an executable which may be run from the command line.
+It takes a regular expression
+from the standard input
+and dumps the random strings.
+
 =head1 ALTERNATIVES
 
 There are at least two alternative modules at CPAN which I have tested.
@@ -243,15 +288,16 @@ The source code of this library is included in the current module.
 I have provided C++ harness code, the XS interface and the Perl module.
 
 
-
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2024 by Andreas Hadjiprocopis.
+This software (except the C++ files) is Copyright (c) 2024 by Andreas Hadjiprocopis.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The C++ files are Copyright (c) by L<daidodo|https://github.com/daidodo> and are L<licensed under Apache v2.0|https://github.com/daidodo/regxstring/blob/master/LICENSE>.
+
 
 =cut
 
